==> crunch-cli-1.1.1.tar.gz: crunch-cli-1.1.1/crunch/inline.py <==
import logging
import os
import sys
import typing

import click
import pandas

from . import command, constants, tester, utils


class _Inline:

    def __init__(self, module: typing.Any, model_directory: str):
        self.module = module
        self.model_directory = model_directory

        self.session = utils.CustomSession(
            os.environ.get(constants.WEB_BASE_URL_ENV_VAR, constants.WEB_BASE_URL_DEFAULT),
            os.environ.get(constants.API_BASE_URL_ENV_VAR, constants.API_BASE_URL_DEFAULT),
            bool(os.environ.get(constants.DEBUG_ENV_VAR, "False")),
        )

        print(f"loaded inline runner with module: {module}")
    
    def load_data(self) -> typing.Tuple[pandas.DataFrame, pandas.DataFrame, pandas.DataFrame]:
        (
            _,
            _,
            x_train_path,
            y_train_path,
            x_test_path
        ) = command.download(self.session)

        x_train = utils.read(x_train_path)
        y_train = utils.read(y_train_path)
        x_test = utils.read(x_test_path)

        return x_train, y_train, x_test

    def test(self, force_first_train=True, train_frequency=1, raise_abort=False):
        try:
            return tester.run(
                self.module,
                self.session,
                self.model_directory,
                force_first_train,
                train_frequency,
            )
        except click.Abort as abort:
            logging.error(f"aborted")

            if raise_abort:
                raise abort

            return None


def load(module_or_module_name: typing.Any, model_directory=constants.DEFAULT_MODEL_DIRECTORY):
    if isinstance(module_or_module_name, str):
        module = sys.modules[module_or_module_name]
    else:
        module = module_or_module_name
    
    return _Inline(module, model_directory)

==> crunch-cli-1.1.3.tar.gz: crunch-cli-1.1.3/crunch/inline.py <==
import logging
import os
import sys
import typing

import click
import pandas

from . import command, constants, tester, utils


class _Inline:

    def __init__(self, module: typing.Any, model_directory: str):
        self.module = module
        self.model_directory = model_directory

        self.session = utils.CustomSession(
            os.environ.get(constants.WEB_BASE_URL_ENV_VAR, constants.WEB_BASE_URL_DEFAULT),
            os.environ.get(constants.API_BASE_URL_ENV_VAR, constants.API_BASE_URL_DEFAULT),
            bool(os.environ.get(constants.DEBUG_ENV_VAR, "False")),
        )

        print(f"loaded inline runner with module: {module}")
    
    def load_data(self) -> typing.Tuple[pandas.DataFrame, pandas.DataFrame, pandas.DataFrame]:
        (
            _,
            _,
            x_train_path,
            y_train_path,
            x_test_path
        ) = command.download(self.session)

        x_train = utils.read(x_train_path)
        y_train = utils.read(y_train_path)
        x_test = utils.read(x_test_path)

        return x_train, y_train, x_test

    def test(self, force_first_train=True, train_frequency=1, raise_abort=False):
        try:
            return tester.run(
                self.module,
                self.session,
                self.model_directory,
                force_first_train,
                train_frequency,
            )
        except click.Abort as abort:
            logging.error(f"Aborted!")

            if raise_abort:
                raise abort

            return None


def load(module_or_module_name: typing.Any, model_directory=constants.DEFAULT_MODEL_DIRECTORY):
    if isinstance(module_or_module_name, str):
        module = sys.modules[module_or_module_name]
    else:
        module = module_or_module_name
    
    return _Inline(module, model_directory)
